@@ -56,9 +56,11 @@ public:
     qlonglong vmSize;
     qlonglong vmRSS;
     qlonglong vmURSS;
+    qlonglong vmPSS;
     qlonglong vmSizeChange;
     qlonglong vmRSSChange;
     qlonglong vmURSSChange;
+    qlonglong vmPSSChange;
     unsigned long pixmapBytes;
     bool hasManagedGuiWindow;
     QString name;
@@ -83,6 +85,8 @@ public:
     Process::Changes changes;
     int elapsedTimeMilliSeconds;
     int noNewPrivileges;
+    QString cGroup;
+    QString macContext;
 };
 
 Process::Process()
@@ -180,9 +184,11 @@ void Process::clear() {
     d->vmSize=0;
     d->vmRSS = 0;
     d->vmURSS = 0;
+    d->vmPSS = 0;
     d->vmSizeChange = 0;
     d->vmRSSChange = 0;
     d->vmURSSChange = 0;
+    d->vmPSSChange = 0;
     d->pixmapBytes = 0;
     d->hasManagedGuiWindow = false;
     d->status=OtherStatus;
@@ -357,6 +363,11 @@ qlonglong Process::vmURSS() const
     return d->vmURSS;
 }
 
+qlonglong Process::vmPSS() const
+{
+    return d->vmPSS;
+}
+
 qlonglong& Process::vmSizeChange() const
 {
     return d->vmSizeChange;
@@ -372,6 +383,11 @@ qlonglong& Process::vmURSSChange() const
     return d->vmURSSChange;
 }
 
+qlonglong Process::vmPSSChange() const
+{
+    return d->vmPSSChange;
+}
+
 unsigned long& Process::pixmapBytes() const
 {
     return d->pixmapBytes;
@@ -487,6 +503,16 @@ int Process::elapsedTimeMilliSeconds() const
     return d->elapsedTimeMilliSeconds;
 }
 
+QString Process::cGroup() const
+{
+    return d->cGroup;
+}
+
+QString Process::macContext() const
+{
+    return d->macContext;
+}
+
 void Process::setParentPid(long int parent_pid)
 {
     d->parent_pid = parent_pid;
@@ -666,6 +692,20 @@ void Process::setVmURSS(qlonglong _vmURSS) {
     d->changes |= Process::VmURSS;
 }
 
+void Process::setVmPSS(qlonglong pss)
+{
+    if (d->vmPSSChange != 0 || d->vmPSS != 0) {
+        d->vmPSSChange = pss - d->vmPSS;
+    }
+
+    if (d->vmPSS == pss) {
+        return;
+    }
+
+    d->vmPSS = pss;
+    d->changes |= Process::VmPSS;
+}
+
 void Process::setName(const QString &_name) {
     if(d->name == _name) return;
     d->name = _name;
@@ -777,4 +817,16 @@ void Process::setChanges(KSysGuard::Process::Change changes)
     d->changes = changes;
 }
 
+void Process::setCGroup(const QString &_cGroup) {
+    if(d->cGroup == _cGroup) return;
+    d->cGroup = _cGroup;
+    d->changes |= Process::Status;
+}
+
+void Process::setMACContext(const QString &_macContext) {
+    if(d->macContext == _macContext) return;
+    d->macContext = _macContext;
+    d->changes |= Process::Status;
+}
+
 }
